@@ -24,7 +24,7 @@ from calculate.lib.datavars import (TableVariable, Variable, ReadonlyVariable,
 from calculate.lib.utils.files import listDirectory, process, PIPE, pathJoin
 from calculate.lib.utils.portage import isPkgInstalled, RepositoryPath
 from calculate.lib.utils.common import cmpVersion
-from calculate.lib.datavars import DataVars
+from calculate.lib.datavars import DataVars, SimpleDataVars
 from itertools import dropwhile
 import re
 import contextlib
@@ -448,8 +448,11 @@ class VariableClEmergeInfo(ReadonlyVariable):
     Emerge --info cache
     """
     type = "list"
+    systemRoot = "/"
 
     def get(self):
+        if self.systemRoot != '/':
+            return []
         return EmergeInfoData()
 
 
@@ -779,3 +782,13 @@ class VariableClHelpSet(ReadonlyVariable):
     """
     type = "bool"
     value = "off"
+
+class DataVarsConfig(SimpleDataVars):
+    """
+    Получить профиль и emerge config из chroot системы
+    """
+    def __init__(self, chroot_path='/'):
+        SimpleDataVars.__init__(
+            self,
+            VariableClMakeProfile(systemRoot=chroot_path),
+            VariableClEmergeConfig(systemRoot=chroot_path))
